@@ -10,6 +10,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -22,13 +25,13 @@
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
+# include "config/vxworks-dummy.h"
 # include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
 # include "config/linux.h"
 # include "config/linux-android.h"
 # include "config/glibc-stdint.h"
-# include "config/vxworks-dummy.h"
 # include "config/mips/mips.h"
 # include "config/mips/gnu-user.h"
 # include "config/mips/linux.h"
@@ -41,8 +44,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
